.. include:: ../README.rst

.. toctree::
   :hidden:
   :caption: User Guide

   guide_basic
   guide_multi_devices
   guide_iter

.. toctree::
   :hidden:
   :caption: Core API Reference

   core
   core_linop
   core_prox
   core_alg
   core_app

.. toctree::
   :hidden:
   :caption: MRI API Reference

   mri
   mri_linop
   mri_app
   mri_rf

.. toctree::
   :hidden:
   :caption: Plot API Reference

   plot
